Package: frmaTools
Version: 1.64.0
Date: 2015-07-08
Title: Frozen RMA Tools
Description: Tools for advanced use of the frma package.
Author: Matthew N. McCall <mccallm@gmail.com>, Rafael A. Irizarry <rafa@jhu.edu>
Maintainer: Matthew N. McCall <mccallm@gmail.com>
Depends: R (>= 2.10.0), affy
Imports: Biobase, DBI, methods, preprocessCore, stats, utils
Suggests: oligo, pd.huex.1.0.st.v2, pd.hugene.1.0.st.v1, frma, affyPLM,
        hgu133aprobe, hgu133atagprobe, hgu133plus2probe, hgu133acdf,
        hgu133atagcdf, hgu133plus2cdf, hgu133afrmavecs, frmaExampleData
biocViews: Software, Microarray, Preprocessing
License: GPL (>= 2)
URL: http://bioconductor.org
git_url: https://git.bioconductor.org/packages/frmaTools
git_branch: RELEASE_3_23
git_last_commit: f7e937f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:09:03 UTC; biocbuild
