Package: @PKGNAME@
Title: Vectors used by frma for microarrays of type @ARRAYTYPE@
Version: @VERSION@
Created: @TODAY@
Author: Matthew N. McCall <mmccall@jhsph.edu>
Description: This package was automatically created by @CREATOR@.
Maintainer: @MAINTAINER@
Depends: R (>= 2.10.0)
License: GPL (>= 2)
biocViews: AnnotationData, AffymetrixChip, @ARRAYTYPE@, @SPECIES@
